Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2775)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java

Issue 2413833002: PaymentRequest: Rename ContactInfo to PayerInfo.
Patch Set: test Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java
index 8b0c0ae3b7524970a9c79fda3f8609edf86b4338..b5f7a3d662a2719cc8928c4c4ae60f9aa34febfa 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestTestBase.java
@@ -209,14 +209,14 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
helper.waitForCallback(callCount);
}
- /** Clicks on an element in the "Contact Info" section of the payments UI. */
- protected void clickInContactInfoAndWait(final int resourceId, CallbackHelper helper)
+ /** Clicks on an element in the "Payer Info" section of the payments UI. */
+ protected void clickInPayerInfoAndWait(final int resourceId, CallbackHelper helper)
throws InterruptedException, TimeoutException {
int callCount = helper.getCallCount();
ThreadUtils.runOnUiThreadBlocking(new Runnable() {
@Override
public void run() {
- mUI.getContactDetailsSectionForTest().findViewById(resourceId).performClick();
+ mUI.getPayerInfoDetailsSectionForTest().findViewById(resourceId).performClick();
}
});
helper.waitForCallback(callCount);
@@ -283,15 +283,15 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
}
/**
* Returns the label corresponding to the contact detail suggestion at the specified
* |suggestionIndex|.
*/
- protected String getContactDetailsSuggestionLabel(final int suggestionIndex)
+ protected String getPayerInfoDetailsSuggestionLabel(final int suggestionIndex)
throws ExecutionException {
return ThreadUtils.runOnUiThreadBlocking(new Callable<String>() {
@Override
public String call() {
- return ((OptionSection) mUI.getContactDetailsSectionForTest())
+ return ((OptionSection) mUI.getPayerInfoDetailsSectionForTest())
.getOptionLabelsForTest(suggestionIndex).getText().toString();
}
});
@@ -308,12 +308,12 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
});
}
- /** Returns the the number of contact detail suggestions. */
- protected int getNumberOfContactDetailSuggestions() throws ExecutionException {
+ /** Returns the the number of payer information detail suggestions. */
+ protected int getNumberOfPayerInfoDetailSuggestions() throws ExecutionException {
return ThreadUtils.runOnUiThreadBlocking(new Callable<Integer>() {
@Override
public Integer call() {
- return ((OptionSection) mUI.getContactDetailsSectionForTest())
+ return ((OptionSection) mUI.getPayerInfoDetailsSectionForTest())
.getNumberOfOptionLabelsForTest();
}
});
@@ -452,6 +452,7 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
@Override
public void run() {
List<EditText> fields = mUI.getEditorView().getEditableTextFieldsForTest();
+
for (int i = 0; i < values.length; i++) {
fields.get(i).setText(values[i]);
}
@@ -283,15 +283,15 @@ abstract class PaymentRequestTestBase extends ChromeActivityTestCaseBase<ChromeT
}
/**
- * Returns the label corresponding to the contact detail suggestion at the specified
+ * Returns the label corresponding to the payer information detail suggestion at the specified
* |suggestionIndex|.
*/

Powered by Google App Engine
This is Rietveld 408576698